@@ -7,9 +7,9 @@ rw.sd <- function (...) {
 pkern.sd <- function (rw.sd, time, paramnames, enclos) {
     if (!all(names(rw.sd) %in% paramnames)) {
         unrec <- names(rw.sd)[!names(rw.sd) %in% paramnames]
-        stop(sQuote("mif2")," error: the following parameter(s), ",
+        stop("in ",sQuote("mif2"),": the following parameter(s), ",
              "which are supposed to be estimated, are not present: ",
-             paste(sapply(sQuote,unrec),collapse=","),
+             paste(sapply(unrec,sQuote),collapse=","),
              call.=FALSE)
     }
     ivp <- function (sd, lag = 1L) {
@@ -21,7 +21,7 @@ pkern.sd <- function (rw.sd, time, paramnames, enclos) {
         if (len==1) {
             sds[[n]] <- rep(sds[[n]],length(time))
         } else if (len!=length(time)) {
-            stop(sQuote("mif2")," error: ",sQuote("rw.sd"),
+            stop("in ",sQuote("mif2"),": ",sQuote("rw.sd"),
                  " spec for parameter ",sQuote(n),
                  " does not evaluate to a vector of the correct length (",
                  length(time),")",call.=FALSE)
@@ -44,6 +44,32 @@ setClass(
     )
 )
 
+mif2.cooling <- function (type, fraction, ntimes) {
+    switch(
+        type,
+        geometric={
+            factor <- fraction^(1/50)
+            function (nt, m) {
+                alpha <- factor^(nt/ntimes+m-1)
+                list(alpha=alpha,gamma=alpha^2)
+            }
+        },
+        hyperbolic={
+            if (fraction < 1) {
+                scal <- (50*ntimes*fraction-1)/(1-fraction)
+                function (nt, m) {
+                    alpha <- (1+scal)/(scal+nt+ntimes*(m-1))
+                    list(alpha=alpha,gamma=alpha^2)
+                }
+            } else {
+                function (nt, m) {
+                    list(alpha=1,gamma=1)
+                }
+            }
+        }
+    )
+}
+
 mif2.pfilter <- function (object, params, Np,
                           mifiter, rw.sd, cooling.fn,
                           tol = 1e-17, max.fail = Inf,
@@ -51,6 +77,8 @@ mif2.pfilter <- function (object, params, Np,
                           .indices = integer(0),
                           .getnativesymbolinfo = TRUE) {
 
+    ep <- paste0("in ",sQuote("mif2.pfilter"),": ")
+
     gnsi <- as.logical(.getnativesymbolinfo)
     transform <- as.logical(transform)
     verbose <- as.logical(verbose)
@@ -59,7 +87,8 @@ mif2.pfilter <- function (object, params, Np,
 
     do_ta <- length(.indices)>0L
     if (do_ta && length(.indices)!=Np[1L])
-        stop(".indices has improper length",call.=TRUE)
+        stop(ep,sQuote(".indices"),
+             " has improper length",call.=FALSE)
     
     times <- time(object,t0=TRUE)
     ntimes <- length(times)-1
@@ -72,7 +101,7 @@ mif2.pfilter <- function (object, params, Np,
 
         ## perturb parameters
         pmag <- cooling.fn(nt,mifiter)$alpha*rw.sd[,nt]
-        .Call(randwalk_perturbation,params,pmag) # NB: 'params' is modified!
+        params <- .Call(randwalk_perturbation,params,pmag)
 
         if (transform)
             tparams <- partrans(object,params,dir="fromEstimationScale",
@@ -84,7 +113,7 @@ mif2.pfilter <- function (object, params, Np,
         }
 
         ## advance the state variables according to the process model
-        X <- try(
+        X <- tryCatch(
             rprocess(
                 object,
                 xstart=x,
@@ -93,14 +122,14 @@ mif2.pfilter <- function (object, params, Np,
                 offset=1,
                 .getnativesymbolinfo=gnsi
             ),
-            silent=TRUE
+            error = function (e) {
+                stop(ep,"process simulation error: ",
+                     conditionMessage(e),call.=FALSE)
+            }
         )
-        if (inherits(X,'try-error'))
-            stop("in ",sQuote("mif2.pfilter"),": process simulation error:",
-                 X,call.=FALSE)
 
         ## determine the weights
-        weights <- try(
+        weights <- tryCatch(
             dmeasure(
                 object,
                 y=object@data[,nt,drop=FALSE],
@@ -110,14 +139,22 @@ mif2.pfilter <- function (object, params, Np,
                 log=FALSE,
                 .getnativesymbolinfo=gnsi
             ),
-            silent=TRUE
+            error = function (e) {
+                stop(ep,"error in calculation of weights: ",
+                     conditionMessage(e),call.=FALSE)
+            }
         )
-        if (inherits(weights,'try-error'))
-            stop("in ",sQuote("mif2.pfilter"),": error in calculation of weights: ",
-                 weights,call.=FALSE)
-        if (!all(is.finite(weights)))
-            stop(sQuote("mif2.pfilter")," error: ",sQuote("dmeasure"),
-                 " returns non-finite value",call.=FALSE)
+        if (!all(is.finite(weights))) {
+            first <- which(!is.finite(weights))[1L]
+            datvals <- object@data[,nt]
+            weight <- weights[first]
+            states <- X[,first,1L]
+            params <- params[,first]
+            cat("Non-finite likelihood computed:\n")
+            cat("likelihood, data, states, and parameters are:\n")
+            print(c(lik=weight,datvals,states,params))
+            stop(ep,sQuote("dmeasure")," returns non-finite value.",call.=FALSE)
+        }
         gnsi <- FALSE
 
         ## compute weighted mean at last timestep
@@ -126,7 +163,7 @@ mif2.pfilter <- function (object, params, Np,
 
         ## compute effective sample size, log-likelihood
         ## also do resampling if filtering has not failed
-        xx <- try(
+        xx <- tryCatch(
             .Call(
                 pfilter_computations,
                 x=X,
@@ -141,12 +178,11 @@ mif2.pfilter <- function (object, params, Np,
                 weights=weights,
                 tol=tol
             ),
-            silent=TRUE
+            error = function (e) {
+                stop(ep,"particle-filter error: ",
+                     conditionMessage(e),call.=FALSE)
+            }
         )
-        if (inherits(xx,'try-error')) {
-            stop("in ",sQuote("mif2.pfilter"),": pfilter computation error: ",
-                 xx,call.=FALSE)
-        }
         all.fail <- xx$fail
         loglik[nt] <- xx$loglik
         eff.sample.size[nt] <- xx$ess
@@ -162,7 +198,7 @@ mif2.pfilter <- function (object, params, Np,
             if (verbose)
                 message("filtering failure at time t = ",times[nt+1])
             if (nfail>max.fail)
-                stop(sQuote("mif2.pfilter")," error: too many filtering failures",call.=FALSE)
+                stop(ep,"too many filtering failures",call.=FALSE)
         }
 
         if (verbose && (nt%%5==0))
@@ -170,10 +206,17 @@ mif2.pfilter <- function (object, params, Np,
 
     }
 
-    if (nfail>0)
-        warning(sprintf(ngettext(nfail,msg1="%d filtering failure occurred in ",
-                                 msg2="%d filtering failures occurred in "),nfail),
-                sQuote("mif2.pfilter"),call.=FALSE)
+    if (nfail>0) {
+        warning(
+            ep,nfail,
+            ngettext(
+                nfail,
+                msg1=" filtering failure occurred.",
+                msg2=" filtering failures occurred."
+            ),
+            call.=FALSE
+        )
+    }
 
     new(
         "pfilterd.pomp",
@@ -191,12 +234,14 @@ mif2.pfilter <- function (object, params, Np,
 
 mif2.internal <- function (object, Nmif, start, Np, rw.sd, transform = FALSE,
                            cooling.type, cooling.fraction.50,
-                           tol = 1e17, max.fail = Inf,
+                           tol = 1e-17, max.fail = Inf,
                            verbose = FALSE, .ndone = 0L,
                            .indices = integer(0),
                            .paramMatrix = NULL,
                            .getnativesymbolinfo = TRUE, ...) {
 
+    ep <- paste0("in ",sQuote("mif2"),": ")
+
     pompLoad(object)
 
     transform <- as.logical(transform)
@@ -204,22 +249,22 @@ mif2.internal <- function (object, Nmif, start, Np, rw.sd, transform = FALSE,
     gnsi <- as.logical(.getnativesymbolinfo)
     Np <- c(Np,Np[1L])
 
-    cooling.fn <- mif.cooling.function(
+    if (Nmif <= 0) stop(ep,sQuote("Nmif"),
+                        " must be a positive integer",call.=FALSE)
+    
+    cooling.fn <- mif2.cooling(
         type=cooling.type,
-        perobs=TRUE,
         fraction=cooling.fraction.50,
         ntimes=length(time(object))
     )
 
     if (is.null(.paramMatrix)) {
-        if (.ndone > 0) {              # call is from 'continue'
+        if (.ndone > 0) {               # call is from 'continue'
             paramMatrix <- object@paramMatrix
             start <- apply(paramMatrix,1L,mean)
-        } else if (Nmif > 0) {         # initial call
+        } else {                         # initial call
             paramMatrix <- array(data=start,dim=c(length(start),Np[1L]),
                                  dimnames=list(variable=names(start),rep=NULL))
-        } else {                        # no work to do
-            paramMatrix <- array(dim=c(0,0))
         }
     } else {
         paramMatrix <- .paramMatrix
@@ -240,7 +285,7 @@ mif2.internal <- function (object, Nmif, start, Np, rw.sd, transform = FALSE,
     ## iterate the filtering
     for (n in seq_len(Nmif)) {
 
-        pfp <- try(
+        pfp <- tryCatch(
             mif2.pfilter(
                 object=object,
                 params=paramMatrix,
@@ -252,13 +297,13 @@ mif2.internal <- function (object, Nmif, start, Np, rw.sd, transform = FALSE,
                 max.fail=max.fail,
                 verbose=verbose,
                 transform=transform,
-                 .indices=.indices,
+                .indices=.indices,
                 .getnativesymbolinfo=gnsi
             ),
-            silent=TRUE
+            error = function (e) {
+                stop(ep,conditionMessage(e),call.=FALSE)
+            }
         )
-        if (inherits(pfp,"try-error"))
-            stop("in ",sQuote("mif2"),": particle-filter error:",pfp,call.=FALSE)
 
         gnsi <- FALSE
 
@@ -267,7 +312,7 @@ mif2.internal <- function (object, Nmif, start, Np, rw.sd, transform = FALSE,
         conv.rec[n,c(1,2)] <- c(pfp@loglik,pfp@nfail)
         .indices <- pfp@indices
         
-        if (verbose) cat("mif2 iteration ",n," of ",Nmif," completed\n")
+        if (verbose) cat("mif2 iteration",n,"of",Nmif,"completed\n")
 
     }
 
@@ -299,49 +344,49 @@ setMethod(
                            tol = 1e-17, max.fail = Inf,
                            verbose = getOption("verbose"),...) {
 
+        ep <- paste0("in ",sQuote("mif2"),": ")
+
         Nmif <- as.integer(Nmif)
-        if (Nmif<0) stop(sQuote("mif2")," error: ",sQuote("Nmif"),
-                         " must be a positive integer",call.=FALSE)
 
         if (missing(start)) start <- coef(object)
         if (length(start)==0)
-            stop(
-                sQuote("mif2")," error: ",sQuote("start")," must be specified if ",
-                sQuote("coef(object)")," is NULL",
-                call.=FALSE
-            )
+            stop(ep,sQuote("start")," must be specified if ",
+                 sQuote("coef(object)")," is NULL",call.=FALSE)
         if (is.null(names(start)))
-            stop(sQuote("mif2")," error: ",sQuote("start")," must be a named vector",
+            stop(ep,sQuote("start")," must be a named vector",
                  call.=FALSE)
 
         ntimes <- length(time(object))
 
-        if (missing(Np)) {
-            stop(sQuote("mif2")," error: ",sQuote("Np")," must be specified",call.=FALSE) }
+        if (missing(Np))
+            stop(ep,sQuote("Np")," must be specified",call.=FALSE)
         else if (is.function(Np)) {
-            Np <- try(
-                vapply(seq.int(1,ntimes),Np,numeric(1)),
-                silent=FALSE
+            Np <- tryCatch(
+                vapply(seq_len(ntimes),Np,numeric(1)),
+                error = function (e) {
+                    stop(ep,"if ",sQuote("Np"),
+                         " is a function, it must return a single positive integer",
+                         call.=FALSE)
+                }
             )
-            if (inherits(Np,"try-error"))
-                stop(sQuote("mif2")," error: if ",sQuote("Np"),
-                     " is a function, it must return a single positive integer")
         } else if (!is.numeric(Np))
-            stop(sQuote("mif2")," error: ",sQuote("Np"),
-                 " must be a number, a vector of numbers, or a function")
+            stop(ep,sQuote("Np"),
+                 " must be a number, a vector of numbers, or a function",
+                 call.=FALSE)
         if (length(Np)==1) {
             Np <- rep(Np,times=ntimes)
         } else if (length(Np)>ntimes) {
             if (Np[1L] != Np[ntimes+1] || length(Np) > ntimes+1) {
-                warning("in ",sQuote("mif2"),": Np[k] ignored for k > ntimes")
+                warning(ep,"Np[k] ignored for k > ntimes",call.=FALSE)
             }
             Np <- head(Np,ntimes)
         }
         if (any(Np <= 0))
-            stop("number of particles, ",sQuote("Np"),", must always be positive")
+            stop(ep,"number of particles, ",
+                 sQuote("Np"),", must always be positive",call.=FALSE)
 
         if (missing(rw.sd))
-            stop(sQuote("mif2")," error: ",sQuote("rw.sd")," must be specified!",call.=FALSE)
+            stop(ep,sQuote("rw.sd")," must be specified!",call.=FALSE)
         if (!is.matrix(rw.sd)) {
             rw.sd <- pkern.sd(rw.sd,time=time(object),paramnames=names(start),
                               enclos=parent.frame())
@@ -351,8 +396,8 @@ setMethod(
 
         cooling.fraction.50 <- as.numeric(cooling.fraction.50)
         if (cooling.fraction.50 <= 0 || cooling.fraction.50 > 1)
-            stop(sQuote("mif2")," error: ",
-                 sQuote("cooling.fraction.50")," must be in (0,1]",call.=FALSE)
+            stop(ep,sQuote("cooling.fraction.50"),
+                 " must be in (0,1]",call.=FALSE)
 
         mif2.internal(
             object=object,
@@ -418,7 +463,8 @@ setMethod(
 
         ndone <- object@Nmif
 
-        obj <- mif2(object=object,Nmif=Nmif,.ndone=ndone,...)
+        f <- selectMethod("mif2","mif2d.pomp")
+        obj <- f(object=object,Nmif=Nmif,.ndone=ndone,...)
 
         object@conv.rec[ndone+1,c('loglik','nfail')] <- obj@conv.rec[1L,c('loglik','nfail')]
         obj@conv.rec <- rbind(
