@@ -7,18 +7,20 @@ typedef double (*_pomp_rxnrate) (const int *j, const double *t, const double *x,
 			   int *stateindex, int *parindex, int *covarindex, 
 			   int *ncovar, double *covar);
 
-void F77_SUB(rndstart)(void) { GetRNGstate(); }
-void F77_SUB(rndend)(void) { PutRNGstate(); }
 double F77_SUB(unifrnd)(void) { return unif_rand(); }
-double F77_SUB(normrnd)(void) { return norm_rand(); }
-double F77_SUB(poisrnd)(double lambda) { return rpois(lambda); }
-double F77_SUB(gammarnd)(double shape, double scale) { return rgamma(shape,scale); }
-void F77_SUB(multinomrnd)(int N, double *p, int ncat, int *ix) { rmultinom(N,p,ncat,ix); }
+double F77_SUB(gammarnd)(int *shapep, double *rate) { 
+  double shape = (double) *shapep;
+  double scale = 1.0/(*rate);
+  return rgamma(shape,scale);
+}
+void F77_SUB(multinomrnd)(int *N, double *p, int *ncat, int *ix) { 
+  rmultinom(*N,p,*ncat,ix); 
+}
 
 void F77_NAME(driverssa)(_pomp_rxnrate fprob, int *nvar, int *nevent, int *npar, int *nreps, int *ntimes, 
 			 int *kflag, double *xstart, double *times, double *params, double *xout,
 			 double *e, double *v, double *d, int *nzero, int *izero, int *istate, 
-			 int *ipar, int *ncov, int *icov, int *lcov, int *mcov, double *tcov, double *cov);
+			 int *ipar, int *ncov, int *icov, int *lcov, int *mcov, double *tcov, double *cov, int *iflag);
 
 // these global objects will pass the needed information to the user-defined function (see 'default_ssa_internal_fn')
 // each of these is allocated once, globally, and refilled many times
@@ -77,7 +79,7 @@ static double default_ssa_rate_fn (int j, double t, const double *x, const doubl
   if (FIRST) {
     if (LENGTH(ans) != 1) {
       UNPROTECT(nprotect);
-      error("user 'rates' must return a single scalar rate");
+      errorcall(R_NilValue,"user 'rates' must return a single scalar rate.");
     }
     FIRST = 0;
   }
@@ -102,6 +104,7 @@ SEXP SSA_simulator (SEXP func, SEXP mflag, SEXP xstart, SEXP times, SEXP params,
   SEXP X, pindex, sindex, cindex, zindex;
   int *sidx, *pidx, *cidx, *zidx;
   SEXP fn, Snames, Pnames, Cnames;
+  int iflag = 0;
 
   dim = INTEGER(GET_DIM(xstart)); nvar = dim[0]; nrep = dim[1];
   dim = INTEGER(GET_DIM(params)); npar = dim[0];
@@ -191,14 +194,18 @@ SEXP SSA_simulator (SEXP func, SEXP mflag, SEXP xstart, SEXP times, SEXP params,
   		      INTEGER(mflag),REAL(xstart),REAL(times),REAL(params),
   		      REAL(X),REAL(e),REAL(vmatrix),REAL(dmatrix),
   		      &nzeros,zidx,sidx,pidx,&ncovars,cidx,
-  		      &covlen,&covdim,REAL(tcovar),REAL(covar));
-
+  		      &covlen,&covdim,REAL(tcovar),REAL(covar),&iflag);
   PutRNGstate();
 
   if (use_native) {
     unset_pomp_userdata();
   }
 
+  if (iflag == 1) 
+    errorcall(R_NilValue,"zero event rate in stochastic simulation algorithm.");
+  else if (iflag == 2) 
+    errorcall(R_NilValue,"negative event rate in stochastic simulation algorithm.");
+
   UNPROTECT(nprotect);
   return X;
 }
@@ -206,5 +213,5 @@ SEXP SSA_simulator (SEXP func, SEXP mflag, SEXP xstart, SEXP times, SEXP params,
 void F77_SUB(tlook) (int *length, int *width, double *tcov, double *cov, double *t, double *y) 
 {
   struct lookup_table tab = {*length, *width, 0, tcov, cov};
-  table_lookup(&tab,*t,y,0);
+  table_lookup(&tab,*t,y);
 }
